/**
 * @author jonasli
 * @module gulp config
 * @date 2016/03/01
 */

'use strict';

let gulp = require('gulp')
let webpack = require('webpack')

let gutil = require('gulp-util')

let webpackConf = require('./webpack.config')
let webpackDevConf = require('./webpack-dev.config')

let src = process.cwd() + '/src'
let dist = process.cwd() + '/dist'

// file copy 
// gulp.task('copy', () => {
//     return gulp.src([
//             src + '/file/**'
//         ])
//         .pipe(gulp.dest(dist+'/file'))
// })

// js check
gulp.task('hint', () => {
    let jshint = require('gulp-jshint')
    let stylish = require('jshint-stylish')

    return gulp.src([
            src + '/components/**/*.js'
        ])
        .pipe(jshint())
        .pipe(jshint.reporter(stylish));
})

// clean dist
gulp.task('clean', ['hint'], () => {
    let clean = require('gulp-clean')

    return gulp.src(dist, {read: true}).pipe(clean())
})

// run webpack pack
gulp.task('pack', ['clean'], (done) => {
    webpack(webpackConf, (err, stats) => {
        if(err) throw new gutil.PluginError('webpack', err)
        gutil.log('[webpack]', stats.toString({colors: true}))
        done()
    })
})

// html process
gulp.task('default', ['pack'], () => {
    let replace = require('gulp-replace')
    let htmlmin = require('gulp-htmlmin')

    return gulp
        .src(dist + '/*.html')
        // @see https://github.com/kangax/html-minifier
        .pipe(htmlmin({
            collapseWhitespace: true,
            removeComments: true
        }))
        .pipe(gulp.dest(dist))
})

// deploy dist to remote server
gulp.task('deploy', () => {
    let sftp = require('gulp-sftp')

    return gulp.src(dist + '/**')
        .pipe(sftp({
            host: '[remote server ip]',
            remotePath: '/www/app/',
            user: 'foo',
            pass: 'bar'
        }))
})
